Nodepool
========

Nodepool is a system for managing test node resources. It supports
launching single-use test nodes from cloud providers as well as managing
access to pre-defined pre-existing nodes. Nodepool is part of a suite of
tools that form a comprehensive test system, including Zuul.

Contents:

.. toctree::
   :maxdepth: 2

   installation
   configuration
   operation
   devguide
   releasenotes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

